==> deepin-draw_5.9.4.orig.tar.xz: deepin-draw-5.9.4/tests/service/test_dbusdraw_adaptor.cpp <==
/*
 * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
 *
 * Author:     Zhang Hao <zhanghao@uniontech.com>
 *
 * Maintainer: WangYu <wangyu@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtest/gtest.h>
#include <gmock/gmock-matchers.h>
#include "dbusdraw_adaptor.h"

//TEST(openFiles, ins1)
//{
//    dbusdraw_adaptor dbus(nullptr);
//    QList<QVariant> testdata;
//    testdata.append(QVariant("./dbus.png"));
//    ASSERT_EQ(false, dbus.openFiles(testdata));
//}

//TEST(openFiles, ins2)
//{
//    dbusdraw_adaptor dbus(nullptr);
//    QList<QVariant> testdata;
//    testdata.append(QVariant("./dbus.png"));
//    testdata.append(QVariant("./test.png"));
//    ASSERT_EQ(false, dbus.openFiles(testdata));
//}

//TEST(openFile, ins5)
//{
//    dbusdraw_adaptor dbus(nullptr);
//    ASSERT_EQ(false, dbus.openFile("./dbus.png"));
//}

//TEST(openFile, ins6)
//{
//    dbusdraw_adaptor dbus(nullptr);
//    ASSERT_EQ(false, dbus.openFile("./test.png"));
//}

==> deepin-draw_5.11.3.orig.tar.xz: deepin-draw-5.11.3/tests/service/test_dbusdraw_adaptor.cpp <==
/*
 * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
 *
 * Author:     Zhang Hao <zhanghao@uniontech.com>
 *
 * Maintainer: WangYu <wangyu@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtest/gtest.h>
#include <gmock/gmock-matchers.h>
//#include "dbusdraw_adaptor.h"

//TEST(openFiles, ins1)
//{
//    dbusdraw_adaptor dbus(nullptr);
//    QList<QVariant> testdata;
//    testdata.append(QVariant("./dbus.png"));
//    ASSERT_EQ(false, dbus.openFiles(testdata));
//}

//TEST(openFiles, ins2)
//{
//    dbusdraw_adaptor dbus(nullptr);
//    QList<QVariant> testdata;
//    testdata.append(QVariant("./dbus.png"));
//    testdata.append(QVariant("./test.png"));
//    ASSERT_EQ(false, dbus.openFiles(testdata));
//}

//TEST(openFile, ins5)
//{
//    dbusdraw_adaptor dbus(nullptr);
//    ASSERT_EQ(false, dbus.openFile("./dbus.png"));
//}

//TEST(openFile, ins6)
//{
//    dbusdraw_adaptor dbus(nullptr);
//    ASSERT_EQ(false, dbus.openFile("./test.png"));
//}
